==> isddc-3.1.0-py3-none-any.whl: isddc/isddc_ssh.py <==
try:
    from paramiko import SSHClient
    from paramiko import AutoAddPolicy
except ModuleNotFoundError:
    SSHClient = None
    AutoAddPolicy = None

from . import isddc_decorator as idec
from . import isddc_func      as ifunc

__default__: SSHClient


@idec.TryExceptAsync(Exception, name='InitSSH')
@idec.RetryAsync('InitSSH', count=10, cycle=10)
async def __init__(params: dict) -> SSHClient:
    client = SSHClient()
    client.set_missing_host_key_policy(AutoAddPolicy())

    for name, value in params.items():
        setattr(client, name, value)

    client.connect(**params)
    ifunc.OverFunc(client.close)

    return client


def cmd(command: str, *, client: SSHClient = None) -> str:
    return (client or __default__).cmd(command)


def put_file(
        local: str = None,
        remote: str = None,
        *,
        client: SSHClient = None
):
    return (client or __default__).put_file(local, remote)


def get_file(
        remote: str = None,
        local: str = None,
        *,
        client: SSHClient = None
):
    return (client or __default__).get_file(local, remote)


if SSHClient:
    def _cmd(self, command: str) -> str:
        _stdin, stdout, stderr = self.exec_command(command)
        result: bytes = stdout.read()
        assert result, f'({command}): "{stderr.read().decode().strip()}"'
        return result.decode().strip()


    def _put_file(self, local: str = None, remote: str = None):
        return self.open_sftp().put(local, remote)


    def _get_file(self, remote: str = None, local: str = None):
        return self.open_sftp.get(remote, local)


    SSHClient.cmd = _cmd
    SSHClient.put_file = _put_file
    SSHClient.get_file = _get_file

==> isddc-3.1.5-py3-none-any.whl: isddc/isddc_ssh.py <==
try:
    from paramiko import SSHClient
    from paramiko import AutoAddPolicy
except ModuleNotFoundError:
    SSHClient = None
    AutoAddPolicy = None

from . import isddc_decorator as idec
from . import isddc_function  as ifunc

__default__: SSHClient


@idec.TryExceptAsync(Exception, name='InitSSH')
@idec.RetryAsync('InitSSH', count=10, cycle=10)
async def __init__(params: dict) -> SSHClient:
    client = SSHClient()
    client.set_missing_host_key_policy(AutoAddPolicy())

    for name, value in params.items():
        setattr(client, name, value)

    client.connect(**params)
    ifunc.OverFunc(client.close)

    return client


def cmd(command: str, *, client: SSHClient = None) -> str:
    return (client or __default__).cmd(command)


def put_file(
        local: str = None,
        remote: str = None,
        *,
        client: SSHClient = None
):
    return (client or __default__).put_file(local, remote)


def get_file(
        remote: str = None,
        local: str = None,
        *,
        client: SSHClient = None
):
    return (client or __default__).get_file(local, remote)


if SSHClient:
    def _cmd(self, command: str) -> str:
        _stdin, stdout, stderr = self.exec_command(command)
        result: bytes = stdout.read()
        assert result, f'({command}): "{stderr.read().decode().strip()}"'
        return result.decode().strip()


    def _put_file(self, local: str = None, remote: str = None):
        return self.open_sftp().put(local, remote)


    def _get_file(self, remote: str = None, local: str = None):
        return self.open_sftp.get(remote, local)


    SSHClient.cmd = _cmd
    SSHClient.put_file = _put_file
    SSHClient.get_file = _get_file
